@@ -24,16 +24,37 @@ import locale
 import glob
 
 
-month_names = {"Jan": 1, "Feb": 2, "Mar": 3, "Apr": 4, "May": 5, "Jun": 6, \
+month_names = {"Jan": 1, "Feb": 2, "Mar": 3, "Apr": 4, "May": 5, "Jun": 6,
     "Jul": 7, "Aug": 8, "Sep": 9, "Oct": 10, "Nov": 11, "Dec": 12}
-zone_names = {"UT": "+0000", "GMT": "+0000", "EST": "-0500", "EDT": "-0400", \
-    "CST": "-0600", "CDT": "-0500", "MST": "-0700", "MDT": "-0600", \
-    "PST": "-0800", "PDT": "-0700", \
+zone_names = {"UT": "+0000", "GMT": "+0000", "EST": "-0500", "EDT": "-0400",
+    "CST": "-0600", "CDT": "-0500", "MST": "-0700", "MDT": "-0600",
+    "PST": "-0800", "PDT": "-0700",
     "Z": "+0000", "A": "-0100", "M": "-1200", "N": "+0100", "Y": "+1200"}
-massage = [(re.compile('<([^<>\s]+)([^<>]*)/>'), \
+massage = [(re.compile('<([^<>\s]+)([^<>]*)/>'),
     lambda x: "<" + x.group(1) + x.group(2) + "></" + x.group(1) + ">")]
 
 
+feed_item_template_default = """
+<b><a class="feedcircuit-item-link"/></b>
+<div class="feedcircuit-item-body">
+</div>
+<br>
+"""
+page_template_default = """
+<html>
+    <head>
+        <meta http-equiv="Content-Type" content="text/html;charset=utf-8" >
+    </head>
+    <body>
+    </body>
+</html>
+"""
+feed_update_template_default = """%title, %timestamp <hr>"""
+item_comment_prefix = "feed item: "
+print_version_keywords_default = [u"версия для печати", u"printable version"]
+cached_comment_prefix = "cached item: "
+
+
 def parse_date(str):
     """ RSS or Atom feed date parsing.
 
@@ -51,7 +72,7 @@ def parse_date(str):
         time_parts = parts[3].split(":")
         if len(time_parts) == 3:
             ss = int(time_parts[2])
-        (y, m, d, hh, mm) = (int(parts[2]), month_names[parts[1]], int(parts[0]), \
+        (y, m, d, hh, mm) = (int(parts[2]), month_names[parts[1]], int(parts[0]),
             int(time_parts[0]), int(time_parts[1]))
     else:
         zone = "+0000"
@@ -123,6 +144,13 @@ def get_or_create_tag(html, list, tag = None):
         return sub
 
 
+def get_feedcircuit_root(html):
+    root = html.find("div", {"id": "feedcircuit-root"})
+    if not root:
+        root = get_or_create_tag(html, ["body"])
+    return root
+
+
 def tag_contains(tag, another):
     if tag:
         while another:
@@ -279,14 +307,9 @@ class Item:
     to have all this fields accessible via self.
     """
 
-    page_template_default = '<html><head><meta http-equiv="Content-Type" content="text/html;charset=utf-8" ></head><body></body></html>'
-    print_version_keywords_default = [u"версия для печати", u"printable version"]
-    cached_comment_prefix = "cached item: "
-
-
-    def __init__(self, url = None, tag = None, base = None, path = "", cache_path = "", callback = None, \
-        page_template = None, print_version_keywords = None, try_use_print_version = True, \
-        allow_scripts = False, as_is = False, content_kwargs = None, reformatter_url = None, next_page_keyword = None, \
+    def __init__(self, url = None, tag = None, base = None, path = "", cache_path = "", callback = None,
+        page_template = None, print_version_keywords = None, try_use_print_version = True,
+        allow_scripts = False, as_is = False, content_kwargs = None, reformatter_url = None, next_page_keyword = None,
         downloader = None):
         """ It is clear that this is constructor :)
 
@@ -315,10 +338,10 @@ class Item:
         self.__cache_path = cache_path
         self.__try_use_print_version = try_use_print_version
         self.__allow_scripts = allow_scripts
-        self.__page_template = self.page_template_default
+        self.__page_template = page_template_default
         if page_template:
             self.__page_template = page_template
-        self.__print_version_keywords = self.print_version_keywords_default
+        self.__print_version_keywords = print_version_keywords_default
         if print_version_keywords:
             self.__print_version_keywords = print_version_keywords
         self.__callback = callback
@@ -468,7 +491,7 @@ class Item:
                 url = urljoin(base, tag[attr])
                 path_for_url = self.__downloader.queue(url, 
                     self.__get_cache_directory(), self.__cache_path)
-                tag.parent.append(Comment(NavigableString(self.cached_comment_prefix + path_for_url)))
+                tag.parent.append(Comment(NavigableString(cached_comment_prefix + path_for_url)))
                 tag[attr] = path_for_url
             except Exception, ex:
                 self.__report("error", ex)
@@ -497,7 +520,7 @@ class Item:
         else:
             content = [node for node in self.__tag.contents]
         if self.__next_page_a:
-            content.append(Comment(NavigableString(self.cached_comment_prefix + self.__next_page_a["href"])))
+            content.append(Comment(NavigableString(cached_comment_prefix + self.__next_page_a["href"])))
             if not tag_contains(self.__tag, self.__next_page_a):
                 self.__next_page_a.extract()
                 content.append(self.__next_page_a)
@@ -510,8 +533,8 @@ class Item:
         if not title:
             title = self.title
         get_or_create_tag(html, ["head", "title"]).append(NavigableString(title))
-        body = get_or_create_tag(html, ["body"])
-        [body.append(tag) for tag in self.__contents]
+        root = get_feedcircuit_root(html)
+        [root.append(tag) for tag in self.__contents]
         if not filename:
             filename = uuid.uuid1().hex + ".html"
         f = open(os.path.join(self.__path, filename), "w")
@@ -528,13 +551,9 @@ class Item:
                 self.__extract_tag()
             self.__contents = self.__fixup_tag()
         except BaseException, ex:
-            self.__report("error", ex)
             self.__downloader.wait_completion()
             self.delete()
-            if isinstance(ex, Exception):
-                self.__contents.append(NavigableString(str(ex)))
-            else:
-                raise
+            raise
         return self.__contents
 
 
@@ -550,9 +569,9 @@ class Item:
 
 
     def __delete_cached_items(self, tag, path):
-        items_to_delete = tag.findAll(text = lambda text: \
-            isinstance(text, Comment) and text.startswith(self.cached_comment_prefix))
-        [self.__delete_cached_item(os.path.join(path, item[len(self.cached_comment_prefix):])) \
+        items_to_delete = tag.findAll(text = lambda text:
+            isinstance(text, Comment) and text.startswith(cached_comment_prefix))
+        [self.__delete_cached_item(os.path.join(path, item[len(cached_comment_prefix):]))
             for item in items_to_delete]
 
 
@@ -567,15 +586,12 @@ class Item:
 class Feed:
     """ Collection of feed related operations. """
     
-    page_item_template_default = '<b><a/></b><div></div><br>'
-    item_comment_prefix = "feed item: "
-
     def __init__(self, url, path = "", cache_path = "", callback = None, title = None, filename = None,
-        page_template = None, page_item_template = None, print_version_keywords = None, \
-        try_use_print_version = True, delete_before_date = None, allow_scripts = False, \
-        inline_items = False, cache_items = False, include = None, exclude = None, as_is = False,
-        content_kwargs = None, reformatter_url = None, next_page_keyword = None, 
-        new_window = False, always_clear_cache = False):
+        feed_template = None, feed_item_template = None, feed_update_template = None, page_template = None,
+        print_version_keywords = None, try_use_print_version = True, delete_before_date = None,
+        allow_scripts = False, inline_items = False, cache_items = False, include = None,
+        exclude = None, as_is = False, content_kwargs = None, reformatter_url = None,
+        next_page_keyword = None, new_window = False, always_clear_cache = False):
         """ Constructor.
 
         url - feed url.
@@ -584,8 +600,8 @@ class Feed:
         callback - for reporting progress.
         title - if this is not provided it is tried to figure out automatically.
         filename - if this is not provided title.html is used to store feed
-        page_template - used for creating cached items.
-        page_item_template - html used to construct feed item.
+        feed_template - used for creating cached items.
+        feed_item_template - html used to construct feed item.
         print_version_keywords - a list of phrases to scan html document searching for reference to
         printable version.
         try_use_print_version - search for reference to printable version should be performed.
@@ -609,12 +625,18 @@ class Feed:
         self.__callback = callback
         self.__title = title
         self.__filename = filename
-        self.__page_template = Item.page_template_default
+        self.__feed_template = page_template_default
+        if feed_template:
+            self.__feed_template = feed_template
+        self.__feed_item_template = feed_item_template_default
+        if feed_item_template:
+            self.__feed_item_template = feed_item_template
+        self.__page_template = page_template_default
         if page_template:
             self.__page_template = page_template
-        self.__page_item_template = self.page_item_template_default
-        if page_item_template:
-            self.__page_item_template = page_item_template
+        self.__feed_update_template = feed_update_template_default
+        if feed_update_template:
+            self.__feed_update_template = feed_update_template
         self.__print_version_keywords = print_version_keywords
         self.__try_use_print_version = try_use_print_version
         self.__inline_items = inline_items
@@ -681,7 +703,7 @@ class Feed:
 
 
     def __item_exists(self, tag, link):
-        return (self.item_comment_prefix + link) in self._existing_items
+        return (item_comment_prefix + link) in self.__existing_items
 
 
     def __outdated(self, item):
@@ -706,26 +728,57 @@ class Feed:
             path = self.__path
         if cache_path == None:
             cache_path = self.__cache_path
-        return Item(url = url, tag = tag, base = base, path = path, cache_path = cache_path, \
-            callback = self.__callback, try_use_print_version = self.__try_use_print_version, \
-            print_version_keywords = self.__print_version_keywords, allow_scripts = self.__allow_scripts, \
-            as_is = self.__as_is, content_kwargs = self.__content_kwargs, \
-            reformatter_url = self.__reformatter_url, next_page_keyword = self.__next_page_keyword, \
-            downloader = self.__downloader)
+        return Item(url = url, tag = tag, base = base, path = path, cache_path = cache_path,
+            callback = self.__callback, try_use_print_version = self.__try_use_print_version,
+            print_version_keywords = self.__print_version_keywords, allow_scripts = self.__allow_scripts,
+            as_is = self.__as_is, content_kwargs = self.__content_kwargs,
+            reformatter_url = self.__reformatter_url, next_page_keyword = self.__next_page_keyword,
+            downloader = self.__downloader, page_template = self.__page_template)
         
 
+    def __get_update_html(self, html):
+        div = Tag(html, "div")
+        div["class"] = "feedcircuit-update"
+        div["id"] = datetime.today().strftime("%Y%m%d%H%M%S")
+        template = self.__feed_update_template.replace("%title", self.__title.strip())
+        template = template.replace("%timestamp",
+            unicode(datetime.today().strftime("%c").decode(locale.getpreferredencoding())))
+        div.append(BeautifulSoup(template))
+        return div
+
+
+    def __get_item_html(self):
+        template = BeautifulSoup(self.__feed_item_template)
+        item = Tag(template, "div")
+        item["class"] = "feedcircuit-item"
+        item.append(template)
+        item_a = item.find("a", {"class": "feedcircuit-item-link"})
+        if not item_a:
+            item_a = item.find("a")
+            if not item_a:
+                item_a = Tag(template, "a")
+                item.insert(0, item_a)
+            item_a["class"] = "feedcircuit-item-link"
+        item_div = item.find("div", {"class": "feedcircuit-item-body"})
+        if not item_div:
+            item_div = item.find("div")
+            if not item_div:
+                item_div = Tag(template, "div")
+                item.append(item_div)
+            item_div["class"] = "feedcircuit-item-body"
+        return (item, item_a, item_div)
+
+
     def __add_item(self, div, item, percent):
         """ Here Item is get included to feed after executing all dependant operations. """
         link = self.__get_item_link(item)
         title = self.__unquote_special(item.title.string.strip())
         self.__report("processing", title, percent)
-        item_html = BeautifulSoup(self.__page_item_template)
-        div.append(Comment(NavigableString(self.item_comment_prefix + link)))
+        (item_html, item_a, item_div) = self.__get_item_html()
+        div.append(Comment(NavigableString(item_comment_prefix + link)))
         div.append(item_html)
-        item_a = get_or_create_tag(item_html, ["a"])
         item_a["href"] = link
         item_a.append(NavigableString(title))
-        item_div = get_or_create_tag(item_html, ["div"])
         if self.__inline_items:
             feed_item = self.__create_feed_item(url = link)
             [item_div.append(t) for t in feed_item.process()]
@@ -739,7 +792,8 @@ class Feed:
                 item_a["href"] = os.path.join(self.__cache_path, feed_item.save(title))
                 if self.__new_window:
                     item_a["target"] = "_blank"
-                item_div.insert(0, Comment(NavigableString(Item.cached_comment_prefix + item_a["href"])))
+                item_div.insert(0, Comment(NavigableString(cached_comment_prefix + item_a["href"])))
+
 
 
     def __delete_div(self, div):
@@ -749,22 +803,21 @@ class Feed:
 
 
     def __delete_all_divs(self, html):
-        if html.body:
-            for div in html.body.findAll(name = "div", recursive = False):
-                self.__delete_div(div)
+        for div in get_feedcircuit_root(html).findAll(name = "div", recursive = False):
+            self.__delete_div(div)
 
 
     def __delete_before(self, html):
         if self.__delete_before_date:
-            divs = filter(lambda div: \
-                div.has_key("id") and datetime.strptime(div["id"], "%Y%m%d%H%M%S").date() < self.__delete_before_date, \
-                html.body.findAll("div", recursive = False))
+            divs = filter(lambda div:
+                div.has_key("id") and datetime.strptime(div["id"], "%Y%m%d%H%M%S").date() < self.__delete_before_date,
+                get_feedcircuit_root(html).findAll("div", recursive = False))
             [self.__delete_div(div) for div in divs]
 
 
     def __get_new_item_count(self, tag):
         return len(tag.findAll(text = lambda text: isinstance(text, Comment)
-            and text.startswith(self.item_comment_prefix)))
+            and text.startswith(item_comment_prefix)))
 
 
     def update(self):
@@ -797,17 +850,12 @@ class Feed:
                     self.__delete_all_divs(html)
                 f.close()
             else:
-                html = BeautifulSoup(self.__page_template)
+                html = BeautifulSoup(self.__feed_template)
                 get_or_create_tag(html, ["head", "title"]).append(NavigableString(self.__title))
-            self._existing_items = html.findAll(text = lambda text: \
-                isinstance(text, Comment) and text.startswith(self.item_comment_prefix))
-            div = Tag(html, "div")
-            div["id"] = datetime.today().strftime("%Y%m%d%H%M%S")
-            update_str = self.__title + ", " + \
-                unicode(datetime.today().strftime("%c").decode(locale.getpreferredencoding()))
-            div.append(NavigableString(update_str))
-            div.append(Tag(html, "hr"))
-            get_or_create_tag(html, ["body"]).insert(0, div)
+            self.__existing_items = html.findAll(text = lambda text:
+                isinstance(text, Comment) and text.startswith(item_comment_prefix))
+            div = self.__get_update_html(html)
+            get_feedcircuit_root(html).insert(0, div)
             to_process = []
             for item in xml.findAll(["item", "entry"]):
                 link = self.__get_item_link(item)
@@ -816,7 +864,10 @@ class Feed:
                     to_process.append(item)
             count = len(to_process)
             for i in range(count):
-                self.__add_item(div, to_process[i], 20 + (i * 60 / count))
+                try:
+                    self.__add_item(div, to_process[i], 20 + (i * 60 / count))
+                except Exception, ex:
+                    self.__report("error", ex)
             result = self.__get_new_item_count(div)
             if result:
                 if not self.__always_clear_cache:
@@ -832,6 +883,7 @@ class Feed:
             self.__downloader.wait_completion()
             if div:
                 self.__delete_div(div)
+            raise
         return result
 
 
@@ -847,3 +899,10 @@ class Feed:
             f.close()
             self.__delete_all_divs(html)
             os.remove(path)
+
+
+    def test(self):
+        start = datetime.today()
+        for i in range(1000):
+            self.__get_item_html()
+        print "self.__get_item_html() 1000 times", datetime.today() - start
