@@ -20,12 +20,25 @@ import shutil
 import sys
 from BeautifulSoup import BeautifulStoneSoup
 
+feed_template_default = """
+<html>
+    <head>
+        <meta http-equiv="Content-Type" content="text/html;charset=utf-8" >
+        %(style)s
+    </head>
+    <body>
+    </body>
+</html>
+"""
+feed_style_default = "<style> body, table { font-size: large } </style>"
+custom_style = '<link rel="stylesheet" href="%(filename)s" type="text/css" />'
+
 gtk.gdk.threads_init()
 
 #This is to be able to start Feed Circuit on PC
 try:
     import osso
-    osso_context = osso.Context("org.maemo.feedcircuit", "0.7.0", False)
+    osso_context = osso.Context("org.maemo.feedcircuit", "0.7.1", False)
 except ImportError:
     pass
 
@@ -42,7 +55,9 @@ try:
         global func_to_exec, args_to_use
         if event.get_status() == conic.STATUS_CONNECTED:
             if func_to_exec:
-                func_to_exec(*args_to_use)
+                gobject.idle_add(func_to_exec, *args_to_use)
+                func_to_exec = None
+        elif event.get_status() == conic.STATUS_DISCONNECTED:
                 func_to_exec = None
 
 
@@ -50,19 +65,58 @@ try:
     connection.connect("connection-event", connection_cb, None)
 
 
-    def connect_and_exec(func, *args):
+    def connect_and_exec(auto, id, func, *args):
         global func_to_exec, args_to_use
         func_to_exec = func
         args_to_use = args
-        connection.request_connection(conic.CONNECT_FLAG_NONE)
+        if auto:
+            if id:
+                connection.request_connection_by_id(id, conic.CONNECT_FLAG_NONE)
+            else:
+                connection.request_connection(conic.CONNECT_FLAG_AUTOMATICALLY_TRIGGERED)
+        else:
+            connection.request_connection(conic.CONNECT_FLAG_NONE)
+
+
+    def get_connections():
+        return [ (iap.get_id(), iap.get_name()) for iap in connection.get_all_iaps() ]
 
 
 except ImportError:
     
-    def connect_and_exec(func, *args):
+    def connect_and_exec(auto, id, func, *args):
         func(*args)
 
 
+    def get_connections():
+        return [("test1id", "test1"), ("test2id", "test2")]
+
+
+def show_file_chooser(title, parent, action, filename = None):
+    try:
+        dlg = hildon.FileChooserDialog(parent = parent, action = action)
+    except AttributeError:
+        dlg = gtk.FileChooserDialog(title = title, parent = parent, action = action,
+            buttons = (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OK, gtk.RESPONSE_OK))
+    if filename:
+        dlg.set_filename(filename)
+    result = None
+    if dlg.run() == gtk.RESPONSE_OK:
+        result = dlg.get_filename()
+    dlg.destroy()
+    return result
+
+
+def get_file_content(filename):
+    if filename:
+        f = open(filename, "r")
+        try:
+            return f.read()
+        finally:
+            f.close()
+    return None
+
+
 def create_config_dir():
     path = os.path.expanduser("~/.config/feedcircuit")
     if not os.path.exists(path):
@@ -188,8 +242,11 @@ class FeedConfig:
         return self.icon
 
 
+    def get_filename(self):
+        return self.id + ".html"
+
     def get_time(self):
-        filename = os.path.join(self.cache_path, self.id + ".html")
+        filename = os.path.join(self.cache_path, self.get_filename())
         if os.path.exists(filename):
             return datetime.fromtimestamp(os.path.getmtime(filename)).strftime("%c")
         return ""
@@ -324,6 +381,8 @@ class FeedListModel(gtk.GenericTreeModel):
         self.use_checkboxes = parser.getboolean_default("global", "use checkboxes", False)
         self.use_new_window = parser.getboolean_default("global", "use new window", False)
         self.show_banner = parser.getboolean_default("global", "show banner", False)
+        self.autorefresh_time = parser.get_default("global", "autorefresh time", "")
+        self.connection_id = parser.get_default("global", "connection id", "")
         for section in parser.sections():
             if section != "global":
                 feed_config = FeedConfig(
@@ -359,6 +418,8 @@ class FeedListModel(gtk.GenericTreeModel):
             parser.set("global", "use checkboxes", str(self.use_checkboxes))
             parser.set("global", "use new window", str(self.use_new_window))
             parser.set("global", "show banner", str(self.show_banner))
+            parser.set("global", "autorefresh time", self.autorefresh_time)
+            parser.set("global", "connection id", self.connection_id)
             i = 0
             for feed_config in self.list:
                 parser.add_section(feed_config.id)
@@ -384,6 +445,18 @@ class FeedListModel(gtk.GenericTreeModel):
             f.close()
 
 
+    def get_autorefresh_time(self):
+        if self.autorefresh_time:
+            tuple = self.autorefresh_time.split(":")
+            return (int(tuple[0]), int(tuple[1]), 0)
+
+
+    def set_autorefresh_time(self, time):
+        self.autorefresh_time = ""
+        if (time):
+            self.autorefresh_time = "%d:%d" % (time[0], time[1])
+
+
     def rebuild_map(self):
         self.map.clear()
         for i in range(len(self.list)):
@@ -477,6 +550,54 @@ class UrlsWindow(gtk.Dialog):
         self.show_all()
 
 
+class AutorefreshWindow(gtk.Dialog):
+
+
+    def __init__(self, parent):
+        gtk.Dialog.__init__(self, None, parent,
+            gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
+            (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
+             gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
+        self.set_title(_("Automatic refresh"))
+        self.enable_check = gtk.CheckButton()
+        self.enable_check.connect("toggled", self.something_changed)
+        self.time_editor = hildon.TimeEditor()
+        self.time_editor.set_sensitive(False)
+        self.conns = get_connections()
+        self.conns.insert(0, ("", ""))
+        self.connection_combo = gtk.combo_box_new_text()
+        for conn in self.conns:
+            self.connection_combo.append_text(conn[1])
+        self.connection_combo.set_sensitive(False)
+        table = gtk.Table(rows = 2, columns = 2)
+        texts = [_("Refresh automatically"), _("Refresh time")]
+        #texts = [_("Refresh automatically"), _("Refresh time"), _("Connection")]
+        for i in range(0, len(texts)):
+            label = gtk.Label(texts[i])
+            label.set_alignment(1, 0.5)
+            table.attach(label, 0, 1, i, i + 1, xpadding = 3, ypadding = 3)
+        table.attach(self.enable_check, 1, 2, 0, 1, xpadding = 3, ypadding = 3)
+        table.attach(self.time_editor, 1, 2, 1, 2, xpadding = 3, ypadding = 3)
+        #table.attach(self.connection_combo, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
+        self.vbox.add(table)
+        self.show_all()
+
+
+    def something_changed(self, source):
+        self.time_editor.set_sensitive(self.enable_check.get_active())
+        self.connection_combo.set_sensitive(self.enable_check.get_active())
+
+
+    def get_connection_id(self):
+        return self.conns[self.connection_combo.get_active()][0]
+
+
+    def set_connection_id(self, id):
+        for i in range(len(self.conns)):
+            if self.conns[i][0] == id:
+                self.connection_combo.set_active(i)
+
+
 class PreferencesWindow(gtk.Dialog):
 
 
@@ -486,6 +607,9 @@ class PreferencesWindow(gtk.Dialog):
             (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
              gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
         self.set_title(_("Preferences"))
+        self.enable_autorefresh = False
+        self.autorefresh_time = (0, 0, 0)
+        self.connection_id = ""
         hbox = gtk.HBox()
         self.path_entry = gtk.Entry()
         self.path_entry.set_width_chars(24)
@@ -496,7 +620,11 @@ class PreferencesWindow(gtk.Dialog):
         self.checkboxes_check = gtk.CheckButton()
         self.new_win_check = gtk.CheckButton()
         self.show_banner_check = gtk.CheckButton()
-        table = gtk.Table(rows = 4, columns = 2)
+        hbox2 = gtk.HBox()
+        self.autorefresh_button = gtk.Button(_("Automatic refresh"))
+        self.autorefresh_button.connect("clicked", self.autorefresh_button_clicked)
+        hbox2.pack_end(self.autorefresh_button, expand = False)
+        table = gtk.Table(rows = 5, columns = 2)
         texts = [_("Cache path"), _("Show checkboxes"),
             _("Open in new window"), _("Show update banner")]
         for i in range(0, len(texts)):
@@ -507,16 +635,27 @@ class PreferencesWindow(gtk.Dialog):
         table.attach(self.checkboxes_check, 1, 2, 1, 2, xpadding = 3, ypadding = 3)
         table.attach(self.new_win_check, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
         table.attach(self.show_banner_check, 1, 2, 3, 4, xpadding = 3, ypadding = 3)
+        table.attach(hbox2, 1, 2, 4, 5, xpadding = 3, ypadding = 3)
         self.vbox.add(table)
         self.show_all()
 
 
     def choose_button_clicked(self, source):
-        dlg = gtk.FileChooserDialog(title = _("Select folder"), parent = self, action = gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
-            buttons = (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT, gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
-        dlg.set_filename(self.path_entry.get_text())
+        filename = show_file_chooser(_("Select folder"), self,
+            gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER, self.path_entry.get_text())
+        if filename:
+            self.path_entry.set_text(filename)
+
+
+    def autorefresh_button_clicked(self, source):
+        dlg = AutorefreshWindow(self)
+        dlg.enable_check.set_active(self.enable_autorefresh)
+        dlg.time_editor.set_time(*self.autorefresh_time)
+        dlg.set_connection_id(self.connection_id)
         if dlg.run() == gtk.RESPONSE_ACCEPT:
-            self.path_entry.set_text(dlg.get_filename())
+            self.enable_autorefresh = dlg.enable_check.get_active()
+            self.autorefresh_time = dlg.time_editor.get_time()
+            self.connection_id = dlg.get_connection_id()
         dlg.destroy()
 
 
@@ -551,13 +690,13 @@ class ImportWindow(gtk.Dialog):
 
 
     def choose_button_clicked(self, source):
-        dlg = gtk.FileChooserDialog(title = _("Select opml file"), parent = self, action = gtk.FILE_CHOOSER_ACTION_OPEN,
-            buttons = (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT, gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
+        filename = None
         if self.path_entry.get_text():
-            dlg.set_filename(os.path.abspath(self.path_entry.get_text()))
-        if dlg.run() == gtk.RESPONSE_ACCEPT:
-            self.path_entry.set_text(dlg.get_filename())
-        dlg.destroy()
+            filename = os.path.abspath(self.path_entry.get_text())
+        filename = show_file_chooser(_("Select opml file"), self, 
+            gtk.FILE_CHOOSER_ACTION_OPEN, filename)
+        if filename:
+            self.path_entry.set_text(filename)
 
 
     def stock_check_changed(self, source):
@@ -883,13 +1022,15 @@ class Program(hildon.Program):
         self.__view.connect("drag-data-received", self.drag_data_received)
         self.__view.connect("drag-drop", self.drag_drop)
 
-
         sw = gtk.ScrolledWindow()
         sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         sw.add(self.__view)
         self.__window.add(sw)
         self.__window.add_toolbar(self.__toolbar)
 
+        self.__timer_id = 0
+        self.schedule_next_update()
+
 
     def append_action(self, menu, toolbar, title, stock, callback):
         if stock:
@@ -957,8 +1098,23 @@ class Program(hildon.Program):
         gtk.main_quit()
 
 
+    def schedule_next_update(self):
+        if self.__timer_id:
+            gobject.source_remove(self.__timer_id)
+            self.__timer_id = 0
+        time = self.__model.get_autorefresh_time()
+        if time:
+            now = datetime.now()
+            next_time = datetime(now.year, now.month, now.day, time[0], time[1], time[2])
+            if next_time < (now + timedelta(seconds = 10)):
+                next_time = next_time + timedelta(1)
+            delta = next_time - now
+            self.__timer_id = gobject.timeout_add(
+                (delta.days * 24 * 3600 + delta.seconds) * 1000, self.auto_refresh)
+
+
     def open_feed(self, feed_config):
-        path = os.path.join(self.__model.cache_path, feed_config.id + ".html")
+        path = os.path.join(self.__model.cache_path, feed_config.get_filename())
         if os.path.exists(path):
             new_win = 0
             if self.__model.use_new_window:
@@ -974,6 +1130,32 @@ class Program(hildon.Program):
             msg_dlg.destroy()
 
 
+    def get_file_name(self, id, suffix):
+        filename = os.path.join(self.__model.config_path, id + "." + suffix)
+        if os.path.exists(filename):
+            return filename
+        filename = os.path.join(self.__model.config_path, suffix)
+        if os.path.exists(filename):
+            return filename
+        return None
+
+    
+    def get_templates(self, id):
+        item = get_file_content(self.get_file_name(id, "item.template.html"))
+        update = get_file_content(self.get_file_name(id, "update.template.html"))
+        feed = get_file_content(self.get_file_name(id, "feed.template.html"))
+        page = get_file_content(self.get_file_name(id, "page.template.html"))
+        if not feed:
+            style_filename = self.get_file_name(id, "style.css")
+            if style_filename:
+                feed = feed_template_default % {"style": custom_style % {"filename": style_filename}}
+            else:
+                feed = feed_template_default % {"style": feed_style_default}
+            if not page:
+                page = feed
+        return (item, update, feed, page)
+
+
     def set_banner_text(self, text):
         if self.__progress_banner:
             self.__progress_banner.set_text(text)
@@ -1006,6 +1188,21 @@ class Program(hildon.Program):
         self.open_feed(self.__model.list[path[0]])
 
 
+    def save_log(self):
+        try:
+            f = open(os.path.join(self.__model.config_path, "refresh.log"), "w")
+            try:
+                f.writelines(self.__log)
+            finally:
+                f.close()
+        except:
+            pass
+
+
+    def log(self, text):
+        self.__log.append("%s %s\n" % (datetime.today().isoformat(), text))
+
+
     def abort(self, source):
         self.__abort_lock.acquire()
         self.__aborted = True
@@ -1017,15 +1214,17 @@ class Program(hildon.Program):
     def update_started(self):
         self.__abort_button.set_sensitive(True)
         self.__abort_button.show()
+        self.__log = []
 
 
     def update_status(self, feed_config, action, item, i, feed_count, percent, j, url_count):
         if percent:
             feed_config.progress = (j * 100 + percent) / url_count
             self.__model.refresh(feed_config.id)
+        text = "(%u/%u) %s %s" % (i, feed_count, _(action), item)
         if self.__model.show_banner:
-            self.set_banner_text( \
-                "(%u/%u) %s %s" % (i, feed_count, _(action), item))
+            self.set_banner_text(text)
+        self.log(text)
 
 
     def update_feed_complete(self, feed_config, new_item_count):
@@ -1039,6 +1238,7 @@ class Program(hildon.Program):
             self.__progress_banner.destroy()
             self.__progress_banner = None
         self.__abort_button.hide()
+        self.save_log()
 
 
     def callback(self, item):
@@ -1048,8 +1248,8 @@ class Program(hildon.Program):
         self.__abort_lock.release()
         if abort:
             sys.exit()
-        gobject.idle_add(self.update_status, self.__progress_info[0], item[0], item[1], \
-            self.__progress_info[1], self.__progress_info[2], item[2], \
+        gobject.idle_add(self.update_status, self.__progress_info[0], item[0], item[1],
+            self.__progress_info[1], self.__progress_info[2], item[2],
             self.__progress_info[3], self.__progress_info[4])
 
 
@@ -1067,33 +1267,42 @@ class Program(hildon.Program):
                 urls = feed_config.get_urls()
                 url_count = len(urls)
                 feed_count = len(feed_configs)
+                (item_t, update_t, feed_t, page_t) = self.get_templates(feed_config.id)
                 title = None
                 if url_count == 1:
                     title = feed_config.name
                 j = 0
                 try:
                     for url in urls:
-                        self.__progress_info = (feed_config, i, feed_count, j, url_count)
-                        del_before = None
-                        clear_cache = True
-                        if feed_config.days_to_keep:
-                            del_before = date.today() - timedelta(feed_config.days_to_keep)
-                            clear_cache = False
-                        feed = feedcircuit.Feed(url = url, path = self.__model.cache_path, cache_path = ".cache",
-                            title = title, filename = feed_config.id + ".html",
-                            callback = self.callback, try_use_print_version = not feed_config.ignore_print_version,
-                            delete_before_date = del_before, always_clear_cache = clear_cache,
-                            inline_items = feed_config.mode == FeedConfig.mode_inline,
-                            cache_items = feed_config.mode == FeedConfig.mode_cache,
-                            include = feed_config.include, exclude = feed_config.exclude,
-                            as_is = feed_config.as_is, content_kwargs = feed_config.get_content_kwargs(),
-                            print_version_keywords = feed_config.get_print_version_keywords(),
-                            reformatter_url = feed_config.reformatter_url, next_page_keyword = feed_config.next_page_link,
-                            new_window = self.__model.use_new_window)
-                        new_item_count += feed.update()
-                        j += 1
+                        try:
+                            self.__progress_info = (feed_config, i, feed_count, j, url_count)
+                            del_before = None
+                            clear_cache = True
+                            if feed_config.days_to_keep:
+                                del_before = date.today() - timedelta(feed_config.days_to_keep)
+                                clear_cache = False
+                            feed = feedcircuit.Feed(url = url, path = self.__model.cache_path, cache_path = ".cache",
+                                title = title, filename = feed_config.get_filename(),
+                                callback = self.callback, try_use_print_version = not feed_config.ignore_print_version,
+                                delete_before_date = del_before, always_clear_cache = clear_cache,
+                                inline_items = feed_config.mode == FeedConfig.mode_inline,
+                                cache_items = feed_config.mode == FeedConfig.mode_cache,
+                                include = feed_config.include, exclude = feed_config.exclude,
+                                as_is = feed_config.as_is, content_kwargs = feed_config.get_content_kwargs(),
+                                print_version_keywords = feed_config.get_print_version_keywords(),
+                                reformatter_url = feed_config.reformatter_url,
+                                next_page_keyword = feed_config.next_page_link,
+                                new_window = self.__model.use_new_window,
+                                feed_item_template = item_t, feed_update_template = update_t,
+                                page_template = page_t, feed_template = feed_t)
+                            new_item_count += feed.update()
+                            j += 1
+                        except Exception:
+                            pass
                 finally:
                     gobject.idle_add(self.update_feed_complete, feed_config, new_item_count)
+        except BaseException:
+            pass
         finally:
             gobject.idle_add(self.update_complete)
             self.__update_lock.release()
@@ -1104,8 +1313,16 @@ class Program(hildon.Program):
         self.__thread.start()
 
 
+    def auto_refresh(self):
+        try:
+            connect_and_exec(True, self.__model.connection_id,
+                self.update_feeds_async, list(self.__model.list))
+        finally:
+            self.schedule_next_update()
+
+
     def refresh_current(self, source):
-        connect_and_exec(self.update_feeds_async, self.get_selected_feeds())
+        connect_and_exec(False, None, self.update_feeds_async, self.get_selected_feeds())
 
 
     def refresh(self, source):
@@ -1114,7 +1331,7 @@ class Program(hildon.Program):
             feedlist = self.get_selected_feeds()
         if not feedlist:
             feedlist = list(self.__model.list)
-        connect_and_exec(self.update_feeds_async, feedlist)
+        connect_and_exec(False, None, self.update_feeds_async, feedlist)
 
 
     def edit(self, source):
@@ -1181,8 +1398,8 @@ class Program(hildon.Program):
                 for feed_config in selected:
                     feed_config.message_count = 0
                     feed = feedcircuit.Feed(None, path = self.__model.cache_path,
-                        cache_path = ".cache", filename = feed_config.id + ".html")
-                    delete_thread = BannerThread(self.__window, _("deleting cache"))
+                        cache_path = ".cache", filename = feed_config.get_filename())
+                    delete_thread = BannerThread(self.__window, _("clearing cache"))
                     delete_thread.execute(feed.delete)
                     self.__model.refresh(feed_config.id)
                     if not only_cache:
@@ -1196,10 +1413,13 @@ class Program(hildon.Program):
     def move_cache(self, from_path, to_path):
         if not os.path.exists(to_path):
             os.makedirs(to_path)
-        for file in glob.glob(os.path.join(from_path, "*")):
-            filename = os.path.split(file)[1]
-            if filename != "config":
-                shutil.move(file, os.path.join(to_path, filename))
+        for feed_config in self.__model.list:
+            filename = os.path.join(from_path, feed_config.get_filename())
+            if os.path.exists(filename):
+                shutil.move(filename, os.path.join(to_path, feed_config.get_filename()))
+            icon_path = os.path.join(from_path, feed_config.icon_filename)
+            if os.path.exists(icon_path):
+                shutil.move(icon_path, os.path.join(to_path, feed_config.icon_filename))
         dot_cache_path = os.path.join(from_path, ".cache")
         if os.path.exists(dot_cache_path):
             shutil.move(dot_cache_path, os.path.join(to_path, ".cache"))
@@ -1270,11 +1490,8 @@ class Program(hildon.Program):
 
 
     def export_feeds(self, source):
-        dlg = gtk.FileChooserDialog(title = _("Select opml file"), \
-            parent = self.__window, action = gtk.FILE_CHOOSER_ACTION_SAVE,
-            buttons = (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT, gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
-        if dlg.run() == gtk.RESPONSE_ACCEPT:
-            filename = dlg.get_filename()
+        filename = show_file_chooser(_("Select opml file"), self.__window, gtk.FILE_CHOOSER_ACTION_SAVE)
+        if filename:
             if not filename.endswith(".opml"):
                 filename += ".opml"
             f = open(filename, "w")
@@ -1286,14 +1503,12 @@ class Program(hildon.Program):
                 for feed_config in self.__model.list:
                     title = feed_config.name.replace("<", "&lt;").replace(">", "&gt;")
                     for url in feed_config.url.split(" "):
-                        f.write('<outline title="%s" description="%s" xmlUrl="%s" /> \n' % \
+                        f.write('<outline title="%s" description="%s" xmlUrl="%s" /> \n' %
                             (title, title, url))
                 f.write('</body>\n')
                 f.write('</opml>\n')
             finally:
                 f.close()
-        dlg.destroy()
-        
 
 
     def preferences(self, source):
@@ -1303,6 +1518,11 @@ class Program(hildon.Program):
             pref_window.checkboxes_check.set_active(self.__model.use_checkboxes)
             pref_window.new_win_check.set_active(self.__model.use_new_window)
             pref_window.show_banner_check.set_active(self.__model.show_banner)
+            time = self.__model.get_autorefresh_time()
+            if time:
+                pref_window.enable_autorefresh = True
+                pref_window.autorefresh_time = time
+                pref_window.connection_id = self.__model.connection_id
             if pref_window.run() == gtk.RESPONSE_ACCEPT:
                 new_path = os.path.abspath(pref_window.path_entry.get_text())
                 if new_path != self.__model.cache_path:
@@ -1312,6 +1532,11 @@ class Program(hildon.Program):
                 self.__model.set_checkboxes(pref_window.checkboxes_check.get_active())
                 self.__model.use_new_window = pref_window.new_win_check.get_active()
                 self.__model.show_banner = pref_window.show_banner_check.get_active()
+                self.__model.set_autorefresh_time(None)
+                if pref_window.enable_autorefresh:
+                    self.__model.set_autorefresh_time(pref_window.autorefresh_time)
+                    self.__model.connection_id = pref_window.connection_id
+                self.schedule_next_update()
                 self.check_col.set_visible(self.__model.use_checkboxes)
                 self.refresh_selected_item.set_property("visible", 
                     not self.__model.use_checkboxes)
@@ -1329,7 +1554,7 @@ class Program(hildon.Program):
     def about(self, source):
         dialog = gtk.AboutDialog()
         dialog.set_name("FeedCircuit")
-        dialog.set_version("0.7.0")
+        dialog.set_version("0.7.1")
         dialog.set_website("http://feedcircuit.garage.maemo.org")
         dialog.set_authors([_("George Kibardin")])
         dialog.run()
